@@ -3,12 +3,12 @@
 import os
 import yaml
 
-import six
 from six.moves import shlex_quote
 
 from mlflow import data
 from mlflow.exceptions import ExecutionException
 from mlflow.utils.file_utils import get_local_path_or_none
+from mlflow.utils.string_utils import is_string_type
 
 
 MLPROJECT_FILE_NAME = "mlproject"
@@ -36,9 +36,26 @@ def load_project(directory):
 
     # Validate config if docker_env parameter is present
     docker_env = yaml_obj.get("docker_env")
-    if docker_env and not docker_env.get("image"):
-        raise ExecutionException("Docker environment specified but no image "
-                                 "attribute found.")
+    if docker_env:
+        if not docker_env.get("image"):
+            raise ExecutionException("Project configuration (MLproject file) was invalid: Docker "
+                                     "environment specified but no image attribute found.")
+        if docker_env.get("volumes"):
+            if not (isinstance(docker_env["volumes"], list)
+                    and all([isinstance(i, str) for i in docker_env["volumes"]])):
+                raise ExecutionException("Project configuration (MLproject file) was invalid: "
+                                         "Docker volumes must be a list of strings, "
+                                         """e.g.: '["/path1/:/path1", "/path2/:/path2"])""")
+        if docker_env.get("environment"):
+            if not (isinstance(docker_env["environment"], list)
+                    and all([isinstance(i, list) or isinstance(i, str)
+                             for i in docker_env["environment"]])):
+                raise ExecutionException(
+                    "Project configuration (MLproject file) was invalid: "
+                    "environment must be a list containing either strings (to copy environment "
+                    "variables from host system) or lists of string pairs (to define new "
+                    "environment variables)."
+                    """E.g.: '[["NEW_VAR", "new_value"], "VAR_TO_COPY_FROM_HOST"])""")
 
     # Validate config if conda_env parameter is present
     conda_path = yaml_obj.get("conda_env")
@@ -85,7 +102,7 @@ class Project(object):
         ext_to_cmd = {".py": "python", ".sh": os.environ.get("SHELL", "bash")}
         if file_extension in ext_to_cmd:
             command = "%s %s" % (ext_to_cmd[file_extension], shlex_quote(entry_point))
-            if type(command) not in six.string_types:
+            if not is_string_type(command):
                 command = command.encode("utf-8")
             return EntryPoint(name=entry_point, parameters={}, command=command)
         elif file_extension == ".R":
@@ -159,7 +176,7 @@ class Parameter(object):
     """A parameter in an MLproject entry point."""
     def __init__(self, name, yaml_obj):
         self.name = name
-        if isinstance(yaml_obj, str):
+        if is_string_type(yaml_obj):
             self.type = yaml_obj
             self.default = None
         else:
